@@ -16,9 +16,11 @@ import contextlib
 
 from django.conf import settings
 from django.contrib.messages import api as msg_api
-from django.utils.encoding import force_unicode
-from django.utils.translation import ugettext_lazy as _
+from django.utils.encoding import force_str
+from django.utils.translation import gettext_lazy as _
+from glanceclient.common import exceptions as glance_exc
 from horizon import exceptions
+from horizon.utils import http as http_utils
 import muranoclient.client as client
 from muranoclient.common import exceptions as exc
 from muranoclient.glance import client as art_client
@@ -33,8 +35,8 @@ LOG = logging.getLogger(__name__)
 
 def _handle_message(request, message):
     def horizon_message_already_queued(_message):
-        _message = force_unicode(_message)
-        if request.is_ajax():
+        _message = force_str(_message)
+        if http_utils.is_ajax(request):
             for tag, msg, extra in request.horizon['async_messages']:
                 if _message == msg:
                     return True
@@ -59,6 +61,10 @@ def handled_exceptions(request):
         msg = _('Unable to communicate to murano-api server.')
         LOG.exception(msg)
         _handle_message(request, msg)
+    except glance_exc.CommunicationError:
+        msg = _('Unable to communicate to glare-api server.')
+        LOG.exception(msg)
+        _handle_message(request, msg)
     except exc.HTTPUnauthorized:
         msg = _('Check Keystone configuration of murano-api server.')
         LOG.exception(msg)
@@ -83,6 +89,15 @@ def handled_exceptions(request):
         if not reason:
             reason = msg
         _handle_message(request, reason)
+    except (exc.HTTPInternalServerError,
+            glance_exc.HTTPInternalServerError) as e:
+        msg = _("There was an error communicating with server")
+        LOG.exception(msg)
+        reason = muranodashboard_utils.parse_api_error(
+            getattr(e, 'details', ''))
+        if not reason:
+            reason = msg
+        _handle_message(request, reason)
 
 
 def _get_endpoint(request):
@@ -91,7 +106,7 @@ def _get_endpoint(request):
 
     if not endpoint:
         try:
-            endpoint = base.url_for(request, 'application_catalog')
+            endpoint = base.url_for(request, 'application-catalog')
         except exceptions.ServiceCatalogException:
             endpoint = 'http://localhost:8082'
             LOG.warning('Murano API location could not be found in Service '
@@ -99,21 +114,21 @@ def _get_endpoint(request):
     return endpoint
 
 
-def _get_glance_endpoint(request):
-    endpoint = getattr(settings, 'GLANCE_API_URL', None)
+def _get_glare_endpoint(request):
+    endpoint = getattr(settings, 'GLARE_API_URL', None)
     if not endpoint:
         try:
-            endpoint = base.url_for(request, "image")
+            endpoint = base.url_for(request, "artifact")
         except exceptions.ServiceCatalogException:
-            endpoint = 'http://localhost:9292'
-            LOG.warning('Glance API location could not be found in Service '
+            endpoint = 'http://localhost:9494'
+            LOG.warning('Glare API location could not be found in Service '
                         'Catalog, using default: {0}'.format(endpoint))
     return endpoint
 
 
 def artifactclient(request):
-    endpoint = _get_glance_endpoint(request)
-    insecure = getattr(settings, 'GLANCE_API_INSECURE', False)
+    endpoint = _get_glare_endpoint(request)
+    insecure = getattr(settings, 'GLARE_API_INSECURE', False)
     token_id = request.user.token.id
     return art_client.Client(endpoint=endpoint, token=token_id,
                              insecure=insecure, type_name='murano',
