@@ -17,6 +17,7 @@ import copy
 import functools
 import json
 import re
+from urllib import parse
 import uuid
 
 from castellan.common import exception as castellan_exception
@@ -24,7 +25,7 @@ from castellan.common import exception as castellan_exception
 from django.conf import settings
 from django.contrib import auth
 from django.contrib.auth import decorators as auth_dec
-from django.contrib.staticfiles.templatetags.staticfiles import static
+from django.templatetags.static import static
 from django.urls import reverse
 # django.contrib.formtools migration to django 1.8
 # https://docs.djangoproject.com/en/1.8/ref/contrib/formtools/
@@ -37,7 +38,7 @@ from django import shortcuts
 from django.utils import decorators as django_dec
 from django.utils import html
 from django.utils import http as http_utils
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.views.generic import list as list_view
 from horizon import exceptions
 from horizon.forms import views
@@ -48,7 +49,6 @@ from novaclient import exceptions as nova_exceptions
 from openstack_dashboard.api import nova
 from openstack_dashboard.usage import quotas
 from oslo_log import log as logging
-import six
 
 from muranoclient.common import exceptions as exc
 from muranodashboard import api
@@ -68,7 +68,7 @@ LATEST_APPS_QUEUE_LIMIT = 3
 
 class DictToObj(object):
     def __init__(self, **kwargs):
-        for key, value in six.iteritems(kwargs):
+        for key, value in iter(kwargs.items()):
             setattr(self, key, value)
 
 
@@ -127,7 +127,9 @@ def get_categories_list(request):
 def switch(request, environment_id,
            redirect_field_name=auth.REDIRECT_FIELD_NAME):
     redirect_to = request.GET.get(redirect_field_name, '')
-    if not http_utils.is_safe_url(url=redirect_to, host=request.get_host()):
+    if (not http_utils.url_has_allowed_host_and_scheme(
+            url=redirect_to,
+            host=request.get_host())):
         redirect_to = settings.LOGIN_REDIRECT_URL
 
     for env in get_available_environments(request):
@@ -407,7 +409,7 @@ class Wizard(generic_views.PageTitleMixin, views.ModalFormMixin, LazyWizard):
             messages.success(self.request, message)
 
             if do_redirect:
-                return http.HttpResponseRedirect(six.text_type(env_url))
+                return http.HttpResponseRedirect(str(env_url))
             else:
                 srv_id = getattr(srv, '?')['id']
                 return self.create_hacked_response(
@@ -554,8 +556,8 @@ class Wizard(generic_views.PageTitleMixin, views.ModalFormMixin, LazyWizard):
     def aggregate_usages(steps):
         result = collections.defaultdict(dict)
         for step in steps:
-            for region, region_usages in six.iteritems(step):
-                for metric, value in six.iteritems(region_usages):
+            for region, region_usages in iter(step.items()):
+                for metric, value in iter(region_usages.items()):
                     if metric not in result[region]:
                         result[region][metric] = 0
                     result[region][metric] += value
@@ -623,7 +625,7 @@ class IndexView(generic_views.PageTitleMixin, list_view.ListView):
         """
         data = self.object_list
         if data:
-            return http_utils.urlquote_plus(self.get_object_id(data[index]))
+            return parse.quote_plus(self.get_object_id(data[index]))
         else:
             return ''
 
