@@ -13,9 +13,9 @@
 #    under the License.
 
 from django.conf import settings
-from django.core.urlresolvers import reverse
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django.urls import reverse
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 from horizon import exceptions
 from horizon import tables
 from muranoclient.common import exceptions as exc
@@ -42,7 +42,7 @@ class DeleteCategory(policy.PolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Delete Category",
             u"Delete Categories",
             count
@@ -50,7 +50,7 @@ class DeleteCategory(policy.PolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Deleted Category",
             u"Deleted Categories",
             count
