@@ -13,7 +13,7 @@
 #    under the License.
 
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 import horizon
 
 # Load the api rest services into Horizon
@@ -26,6 +26,7 @@ class AppCatalog(horizon.Dashboard):
     default_panel = "environments"
     supports_tenants = True
 
+
 try:
     horizon.base.Horizon.registered('app-catalog')
 except horizon.base.NotRegistered:
