@@ -22,9 +22,9 @@ from django import forms
 from django.forms import widgets
 from django.template import defaultfilters
 from django.urls import reverse
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils import html
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from horizon import exceptions
 from horizon import forms as hz_forms
 from horizon import messages
@@ -37,10 +37,10 @@ from openstack_dashboard.api import glance
 from openstack_dashboard.api import neutron
 from oslo_log import log as logging
 from oslo_log import versionutils
-import six
 from yaql import legacy
 
 from muranodashboard.api import packages as pkg_api
+from muranodashboard.common import designate
 from muranodashboard.common import net
 from muranodashboard.dynamic_ui import helpers
 from muranodashboard.environments import api as env_api
@@ -57,7 +57,7 @@ def with_request(func):
     """
     def update(self, initial, request=None, **kwargs):
         initial_request = initial.get('request')
-        for key, value in six.iteritems(initial):
+        for key, value in iter(initial.items()):
             if key != 'request' and key not in kwargs:
                 kwargs[key] = value
 
@@ -176,11 +176,11 @@ class CustomPropertiesField(forms.Field):
                  *args, **kwargs):
         self.description = description
         self.description_title = (description_title or
-                                  force_text(kwargs.get('label', '')))
+                                  force_str(kwargs.get('label', '')))
 
         for arg in FIELD_ARGS_TO_ESCAPE:
             if kwargs.get(arg):
-                kwargs[arg] = html.escape(force_text(kwargs[arg]))
+                kwargs[arg] = html.escape(force_str(kwargs[arg]))
 
         validators = []
         validators_js = []
@@ -192,11 +192,11 @@ class CustomPropertiesField(forms.Field):
                     error_messages = kwargs.get('error_messages', {})
                     if hasattr(validator, 'code') and \
                        validator.code in error_messages:
-                        regex_message = force_text(
+                        regex_message = force_str(
                             error_messages[validator.code]
                         )
                     validators_js. \
-                        append({'regex': force_text(validator.regex.pattern),
+                        append({'regex': force_str(validator.regex.pattern),
                                 'message': regex_message})
             else:  # mixed list of regexpValidator and YAQL validators
                 expr = validator.get('expr')
@@ -254,8 +254,8 @@ class CharField(forms.CharField, CustomPropertiesField):
 
 
 class PasswordField(CharField):
-    special_characters = '!@#$%^&*()_+|\/.,~?><:{}-'
-    password_re = re.compile('^.*(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*[%s]).*$'
+    special_characters = '!@#$%^&*()_+|\\/.,~?><:{}-'
+    password_re = re.compile(r'^.*(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*[%s]).*$'
                              % special_characters)
     has_clone = False
     original = True
@@ -440,6 +440,9 @@ class KeyPairChoiceField(DynamicChoiceField):
         for keypair in sorted(keypairs, key=lambda e: e.name):
             self.choices.append((keypair.name, keypair.name))
 
+        if len(keypairs) == 1:
+            self.initial = keypairs[0].name
+
 
 class SecurityGroupChoiceField(DynamicChoiceField):
     """This widget allows to select a security group for VMs"""
@@ -498,11 +501,14 @@ class ImageChoiceField(ChoiceField):
                     continue
             image_map[image.id] = title
 
-        for id_, title in sorted(six.iteritems(image_map),
+        for id_, title in sorted(iter(image_map.items()),
                                  key=lambda e: e[1].title):
             image_choices.append((id_, title))
+
         if image_choices:
-            image_choices.insert(0, ("", _("Select Image")))
+            # If only one choice, select it as only option
+            if len(image_choices) != 1:
+                image_choices.insert(0, ("", _("Select Image")))
         else:
             image_choices.insert(0, ("", _("No images available")))
 
@@ -564,7 +570,8 @@ class AZoneChoiceField(ChoiceField):
                               _("Unable to retrieve  availability zones."))
 
         az_choices = [(az.zoneName, az.zoneName)
-                      for az in availability_zones if az.zoneState]
+                      for az in availability_zones
+                      if az.zoneState['available']]
         if not az_choices:
             az_choices.insert(0, ("", _("No availability zones available")))
 
@@ -774,3 +781,25 @@ class DomainChoiceField(make_select_cls('io.murano.windows.ActiveDirectory')):
     def __init__(self, *args, **kwargs):
         super(DomainChoiceField, self).__init__(*args, **kwargs)
         self.choices = [('', _('Not in domain'))]
+
+
+class ZoneChoiceField(ChoiceField):
+    @with_request
+    def update(self, request, form=None, **kwargs):
+        try:
+            zones = designate.zone_list(request)
+        except Exception:
+            zones = []
+            exceptions.handle(request, _("Unable to retrieve DNS zones."))
+
+        # Use zone name instead of ID purely for convenience of being able to
+        # pass it through to construct fqdn for apps
+        zone_choices = [(z['name'], z['name']) for z in zones]
+        zone_choices.sort(key=lambda e: e[1])
+
+        if zones:
+            zone_choices.insert(0, ('', _('No DNS zone')))
+        else:
+            zone_choices.insert(0, ('', _('No DNS zones available')))
+
+        self.choices = zone_choices
