@@ -15,7 +15,7 @@
 from collections import defaultdict
 
 from django import forms
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from oslo_log import log as logging
 from yaql import legacy
 
@@ -51,7 +51,8 @@ TYPES.update({
     'choice': fields.ChoiceField,
     'floatingip': fields.FloatingIpBooleanField,
     'securitygroup': fields.SecurityGroupChoiceField,
-    'volume': fields.VolumeChoiceField
+    'volume': fields.VolumeChoiceField,
+    'zone': fields.ZoneChoiceField,
 })
 
 
