@@ -12,14 +12,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from django.utils.translation import gettext_lazy as _
 import horizon
-from django.utils.translation import ugettext_lazy as _
-from muranodashboard import dashboard
 
 
 class Environments(horizon.Panel):
     name = _("Environments")
     slug = 'environments'
-
-
-dashboard.Murano.register(Environments)
+    policy_rules = (("murano", "list_environments"),)
