@@ -17,7 +17,7 @@ import json
 
 from django.conf import settings
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from heat_dashboard.api import heat as heat_api
 
