@@ -12,10 +12,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core.urlresolvers import reverse
 from django.template import defaultfilters
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django.urls import reverse
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 from horizon import exceptions
 from horizon import messages
 from horizon import tables
@@ -51,7 +51,8 @@ class ImportPackage(tables.LinkAction):
         _allowed = False
         with api.handled_exceptions(request):
             client = api.muranoclient(request)
-            _allowed = client.packages.categories() is not None
+            if client.categories.list():
+                _allowed = True
         return _allowed
 
 
@@ -85,7 +86,7 @@ class ToggleEnabled(tables.BatchAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Toggle Active",
             u"Toggle Active",
             count
@@ -93,7 +94,7 @@ class ToggleEnabled(tables.BatchAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Toggled Active",
             u"Toggled Active",
             count
@@ -121,7 +122,7 @@ class TogglePublicEnabled(tables.BatchAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Toggle Public",
             u"Toggle Public",
             count
@@ -129,7 +130,7 @@ class TogglePublicEnabled(tables.BatchAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Toggled Public",
             u"Toggled Public",
             count
@@ -164,7 +165,7 @@ class DeletePackage(policy.PolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Delete Package",
             u"Delete Packages",
             count
@@ -172,7 +173,7 @@ class DeletePackage(policy.PolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Deleted Package",
             u"Deleted Packages",
             count
