@@ -13,18 +13,18 @@
 # under the License.
 
 import collections
-import mock
-import testtools
+import unittest
+from unittest import mock
 
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from muranoclient.common import exceptions as exc
 from muranodashboard.environments import tables
 from muranodashboard.environments import tabs
 
 
-class TestOverviewTab(testtools.TestCase):
+class TestOverviewTab(unittest.TestCase):
 
     def setUp(self):
         super(TestOverviewTab, self).setUp()
@@ -65,6 +65,7 @@ class TestOverviewTab(testtools.TestCase):
             )
         ]
         mock_request = mock.Mock()
+        mock_request.session = {'django_timezone': 'UTC'}
 
         expected_service = {
             'service': collections.OrderedDict([
@@ -222,7 +223,7 @@ class TestOverviewTab(testtools.TestCase):
                          mock_heat_api.stacks_list.mock_calls)
 
 
-class TestServiceLogsTab(testtools.TestCase):
+class TestServiceLogsTab(unittest.TestCase):
 
     def setUp(self):
         super(TestServiceLogsTab, self).setUp()
@@ -252,7 +253,7 @@ class TestServiceLogsTab(testtools.TestCase):
             mock_request, 'foo_service_id', 'foo_environment_id')
 
 
-class TestEnvLogsTab(testtools.TestCase):
+class TestEnvLogsTab(unittest.TestCase):
 
     def setUp(self):
         super(TestEnvLogsTab, self).setUp()
@@ -265,37 +266,42 @@ class TestEnvLogsTab(testtools.TestCase):
         self.assertFalse(self.env_logs_tab.preload)
 
     def test_get_context_data(self):
-        mock_report = mock.Mock(created='T12:34')
+        mock_report = mock.Mock(created='1970-01-01T12:34:00')
         self.env_logs_tab.tab_group = mock.Mock()
         self.env_logs_tab.tab_group.kwargs = {
             'logs': [mock_report]
         }
+        mock_request = mock.MagicMock()
+        mock_request.session = {'django_timezone': 'UTC'}
 
-        reports = self.env_logs_tab.get_context_data(None)
+        reports = self.env_logs_tab.get_context_data(mock_request)
 
-        mock_report.created = ' 12:34'
+        mock_report.created = '1970-01-01 12:34:00'
         self.assertEqual({'reports': [mock_report]}, reports)
 
 
-class TestLatestLogTab(testtools.TestCase):
+class TestLatestLogTab(unittest.TestCase):
 
     def test_allowed(self):
-        latest_logs_tab = tabs.LatestLogsTab(None)
-        latest_logs_tab.tab_group = mock.Mock()
-        mock_report = mock.Mock(created='T12:34')
-        latest_logs_tab.tab_group.kwargs = {'logs': [mock_report]}
+        mock_request = mock.MagicMock()
+        mock_request.session = {'django_timezone': 'UTC'}
+        mock_report = mock.Mock(created='1970-01-01T12:34:00')
+        tab_group = mock.Mock()
+        tab_group.kwargs = {'logs': [mock_report]}
+        latest_logs_tab = tabs.LatestLogsTab(tab_group, request=mock_request)
 
         self.assertEqual(_('Latest Deployment Log'), latest_logs_tab.name)
-        mock_report.created = ' 12:34'
-        self.assertEqual([mock_report], latest_logs_tab.allowed(None))
+        mock_report.created = '1970-01-01 12:34:00'
+        self.assertEqual([mock_report], latest_logs_tab.allowed(mock_request))
 
 
-class TestEnvConfigTab(testtools.TestCase):
+class TestEnvConfigTab(unittest.TestCase):
 
     def setUp(self):
         super(TestEnvConfigTab, self).setUp()
         mock_tab_group = mock.Mock(kwargs={})
-        self.env_config_tab = tabs.EnvConfigTab(mock_tab_group, None)
+        mock_request = mock.Mock()
+        self.env_config_tab = tabs.EnvConfigTab(mock_tab_group, mock_request)
 
         self.assertEqual(_('Configuration'), self.env_config_tab.name)
         self.assertEqual('env_config', self.env_config_tab.slug)
@@ -317,7 +323,7 @@ class TestEnvConfigTab(testtools.TestCase):
         self.assertEqual(['foo_service'], result)
 
 
-class TestEnvironmentTopologyTab(testtools.TestCase):
+class TestEnvironmentTopologyTab(unittest.TestCase):
 
     def setUp(self):
         super(TestEnvironmentTopologyTab, self).setUp()
@@ -355,7 +361,7 @@ class TestEnvironmentTopologyTab(testtools.TestCase):
 
 
 @mock.patch.object(tabs, 'api')
-class TestEnvironmentServicesTab(testtools.TestCase):
+class TestEnvironmentServicesTab(unittest.TestCase):
 
     def setUp(self):
         super(TestEnvironmentServicesTab, self).setUp()
@@ -441,7 +447,7 @@ class TestEnvironmentServicesTab(testtools.TestCase):
 
 
 @mock.patch.object(tabs, 'api')
-class TestDeploymentTab(testtools.TestCase):
+class TestDeploymentTab(unittest.TestCase):
 
     def setUp(self):
         super(TestDeploymentTab, self).setUp()
@@ -506,7 +512,7 @@ class TestDeploymentTab(testtools.TestCase):
             "horizon:app-catalog:environments:index")
 
 
-class TestEnvironmentDetailsTabs(testtools.TestCase):
+class TestEnvironmentDetailsTabs(unittest.TestCase):
 
     @mock.patch.object(tabs, 'api')
     def test_init(self, mock_api):
@@ -514,8 +520,11 @@ class TestEnvironmentDetailsTabs(testtools.TestCase):
             '{"environment": {"status": "foo_status"}}'
 
         mock_request = mock.Mock(GET={})
+        mock_request.session = {'django_timezone': 'UTC'}
+        mock_logs = mock.Mock(created='1970-01-01T12:34:00')
+        mock_logs.created = '1970-01-01 12:34:00'
         env_details_tabs = tabs.EnvironmentDetailsTabs(
-            mock_request, environment_id='foo_env_id', logs=[mock.Mock()])
+            mock_request, environment_id='foo_env_id', logs=[mock_logs])
 
         self.assertEqual('environment_details', env_details_tabs.slug)
         self.assertEqual(
@@ -525,7 +534,7 @@ class TestEnvironmentDetailsTabs(testtools.TestCase):
         self.assertTrue(env_details_tabs.sticky)
 
 
-class TestServicesTabs(testtools.TestCase):
+class TestServicesTabs(unittest.TestCase):
 
     def test_init(self):
         mock_request = mock.Mock(GET={})
@@ -538,7 +547,7 @@ class TestServicesTabs(testtools.TestCase):
         self.assertTrue(services_tabs.sticky)
 
 
-class TestDeploymentDetailsTabs(testtools.TestCase):
+class TestDeploymentDetailsTabs(unittest.TestCase):
 
     def test_init(self):
         mock_request = mock.Mock(GET={})
