@@ -15,10 +15,10 @@
 import base64
 from django.conf import settings
 from django import http
-from django.utils.translation import ugettext_lazy as _
-import mock
+from django.utils.translation import gettext_lazy as _
 import sys
 import unittest
+from unittest import mock
 
 from horizon import conf
 
@@ -80,6 +80,7 @@ class TestEnvironmentDetails(unittest.TestCase):
         mock_request = mock.Mock()
         mock_request.user.service_catalog = None
         mock_token = mock.MagicMock()
+        mock_request.user.authorized_tenants = [mock.Mock()]
         mock_token.tenant.__getitem__.return_value = 'foo_tenant_id'
         mock_request.session = {'token': mock_token}
         mock_tab_group = mock.Mock()
@@ -170,10 +171,10 @@ class TestDetailServiceView(unittest.TestCase):
         }
         self.mock_request = mock.Mock(GET={})
         self.mock_request.user.service_catalog = None
-        self.mock_request.is_ajax.return_value = True
         self.mock_request.horizon = {
             'async_messages': [('tag', 'msg', 'extra')]
         }
+        mock.patch('horizon.utils.http.is_ajax', return_value=True).start()
         self.detail_service_view.request = self.mock_request
 
         self.assertEqual(env_tabs.ServicesTabs,
