@@ -12,25 +12,25 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
-import testtools
+import unittest
+from unittest import mock
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from muranodashboard.images import forms
 
 
-class TestImagesForms(testtools.TestCase):
+class TestImagesForms(unittest.TestCase):
     def setUp(self):
         super(TestImagesForms, self).setUp()
-        metadata = {'murano_image_info': '{"title": "title", "type": "type"}'}
-        self.mock_img = mock.MagicMock(id=12, properties=metadata)
+        metadata = '{"title": "title", "type": "type"}'
+        self.mock_img = mock.MagicMock(id=12, murano_image_info=metadata)
         self.mock_request = mock.MagicMock()
 
     @mock.patch.object(forms, 'LOG')
     def test_filter_murano_images(self, mock_log):
         mock_blank_img = \
-            mock.MagicMock(id=13, properties={"murano_image_info": "info"})
+            mock.MagicMock(id=13, murano_image_info="info")
         images = [mock_blank_img]
         msg = _('Invalid metadata for image: {0}').format(images[0].id)
         self.assertEqual(images,
@@ -40,8 +40,16 @@ class TestImagesForms(testtools.TestCase):
         images = [self.mock_img]
         self.assertEqual(images, forms.filter_murano_images(images))
 
+        murano_meta = '{"title": "title", "type": "type"}'
 
-class TestMarkImageForm(testtools.TestCase):
+        mock_snapshot_img = mock.MagicMock(
+            id=14, murano_image_info=murano_meta, image_type='snapshot')
+        images = [mock_snapshot_img]
+        self.assertEqual([],
+                         forms.filter_murano_images(images, self.mock_request))
+
+
+class TestMarkImageForm(unittest.TestCase):
     def setUp(self):
         super(TestMarkImageForm, self).setUp()
         self.mock_request = mock.MagicMock()
