@@ -13,9 +13,10 @@
 # under the License.
 
 import json
-import mock
 import unittest
+from unittest import mock
 
+import horizon
 from horizon import exceptions
 
 from muranodashboard.images import tables
@@ -88,7 +89,7 @@ class TestMarkedImagesView(unittest.TestCase):
         self.images_view.request.GET.get.assert_called_once_with(
             tables.MarkedImagesTable._meta.prev_pagination_param, None)
         mock_glance.glanceclient.assert_called_once_with(
-            self.images_view.request, "2")
+            self.images_view.request)
 
     @mock.patch.object(views, 'glance', autospec=True)
     def test_get_data_with_desc_sort_dir(self, mock_glance):
@@ -121,7 +122,7 @@ class TestMarkedImagesView(unittest.TestCase):
             mock.call(tables.MarkedImagesTable._meta.pagination_param, None)
         ])
         mock_glance.glanceclient.assert_called_once_with(
-            self.images_view.request, "2")
+            self.images_view.request)
 
     @mock.patch.object(views, 'glance', autospec=True)
     def test_get_data_with_more_results(self, mock_glance):
@@ -157,13 +158,16 @@ class TestMarkedImagesView(unittest.TestCase):
         self.images_view.request.GET.get.assert_called_once_with(
             tables.MarkedImagesTable._meta.prev_pagination_param, None)
         mock_glance.glanceclient.assert_called_once_with(
-            self.images_view.request, "2")
+            self.images_view.request)
 
     @mock.patch.object(views, 'reverse', autospec=True)
     @mock.patch.object(views, 'glance', autospec=True)
-    def test_get_data_except_glance_image_list_exception(self, mock_glance,
+    @mock.patch.object(horizon.messages, 'horizon_message_already_queued')
+    def test_get_data_except_glance_image_list_exception(self, mock_messages,
+                                                         mock_glance,
                                                          mock_reverse):
         """Test that glance_v1_client.images.list exception is handled."""
+        mock_messages.return_value = True
         mock_glance_client = mock.Mock()
         mock_glance_client.images.list.side_effect = Exception()
         mock_glance.glanceclient.return_value = mock_glance_client
@@ -176,6 +180,6 @@ class TestMarkedImagesView(unittest.TestCase):
         self.assertEqual('foo_reverse_url', e.location)
 
         mock_glance.glanceclient.assert_called_once_with(
-            self.images_view.request, "2")
+            self.images_view.request)
         mock_reverse.assert_called_once_with(
             'horizon:app-catalog:catalog:index')
